# Extended elasticmock with additional cluster and index APIs

elasticmock_additional_apis module has in addition following cluster and index APIs:

  - Cluster Allocation
  - Index Stats, Get, Get_alias

License
----

MIT
